@@ -11,7 +11,7 @@ namespace dxvk {
   D3D11ImmediateContext::D3D11ImmediateContext(
           D3D11Device*    pParent,
     const Rc<DxvkDevice>& Device)
-  : D3D11DeviceContext(pParent, Device),
+  : D3D11DeviceContext(pParent, Device, DxvkCsChunkFlag::SingleUse),
     m_csThread(Device->createContext()) {
     EmitCs([cDevice = m_device] (DxvkContext* ctx) {
       ctx->beginRecording(cDevice->createCommandList());
