@@ -187,6 +187,10 @@ namespace dxvk {
    */
   struct DxbcCompilerCsPart {
     uint32_t functionId = 0;
+
+    uint32_t workgroupSizeX               = 0;
+    uint32_t workgroupSizeY               = 0;
+    uint32_t workgroupSizeZ               = 0;
     
     uint32_t builtinGlobalInvocationId    = 0;
     uint32_t builtinLocalInvocationId     = 0;
@@ -985,7 +989,10 @@ namespace dxvk {
     
     void emitOutputSetup();
     void emitOutputMapping();
+    void emitOutputDepthClamp();
     
+    void emitInitWorkgroupMemory();
+
     //////////////////////////////////////////
     // System value load methods (per shader)
     DxbcRegisterValue emitVsSystemValueLoad(
