@@ -13,6 +13,7 @@ namespace dxvk {
   : m_instance      (instance),
     m_vki           (instance->vki()),
     m_handle        (handle) {
+    this->initHeapAllocInfo();
     this->queryExtensions();
     this->queryDeviceInfo();
     this->queryDeviceFeatures();
@@ -30,6 +31,22 @@ namespace dxvk {
   }
   
   
+  DxvkAdapterMemoryInfo DxvkAdapter::getMemoryHeapInfo() const {
+    VkPhysicalDeviceMemoryProperties props = memoryProperties();
+
+    DxvkAdapterMemoryInfo info = { };
+    info.heapCount = props.memoryHeapCount;
+
+    for (uint32_t i = 0; i < info.heapCount; i++) {
+      info.heaps[i].heapFlags       = props.memoryHeaps[i].flags;
+      info.heaps[i].memoryAvailable = props.memoryHeaps[i].size;
+      info.heaps[i].memoryAllocated = m_heapAlloc[i].load();
+    }
+
+    return info;
+  }
+
+
   VkPhysicalDeviceMemoryProperties DxvkAdapter::memoryProperties() const {
     VkPhysicalDeviceMemoryProperties memoryProperties;
     m_vki->vkGetPhysicalDeviceMemoryProperties(m_handle, &memoryProperties);
@@ -195,7 +212,8 @@ namespace dxvk {
   Rc<DxvkDevice> DxvkAdapter::createDevice(DxvkDeviceFeatures enabledFeatures) {
     DxvkDeviceExtensions devExtensions;
 
-    std::array<DxvkExt*, 12> devExtensionList = {{
+    std::array<DxvkExt*, 13> devExtensionList = {{
+      &devExtensions.amdMemoryOverallocationBehaviour,
       &devExtensions.extShaderViewportIndexLayer,
       &devExtensions.extTransformFeedback,
       &devExtensions.extVertexAttributeDivisor,
@@ -237,6 +255,15 @@ namespace dxvk {
       enabledFeatures.extVertexAttributeDivisor.pNext = enabledFeatures.core.pNext;
       enabledFeatures.core.pNext = &enabledFeatures.extVertexAttributeDivisor;
     }
+
+    // Report the desired overallocation behaviour to the driver
+    VkDeviceMemoryOverallocationCreateInfoAMD overallocInfo;
+    overallocInfo.sType = VK_STRUCTURE_TYPE_DEVICE_MEMORY_OVERALLOCATION_CREATE_INFO_AMD;
+    overallocInfo.pNext = nullptr;
+    overallocInfo.overallocationBehavior = VK_MEMORY_OVERALLOCATION_BEHAVIOR_DISALLOWED_AMD;
+
+    if (m_instance->options().allowMemoryOvercommit)
+      overallocInfo.overallocationBehavior = VK_MEMORY_OVERALLOCATION_BEHAVIOR_ALLOWED_AMD;
     
     // Create one single queue for graphics and present
     float queuePriority = 1.0f;
@@ -271,6 +298,9 @@ namespace dxvk {
     info.enabledExtensionCount      = extensionNameList.count();
     info.ppEnabledExtensionNames    = extensionNameList.names();
     info.pEnabledFeatures           = &enabledFeatures.core.features;
+
+    if (devExtensions.amdMemoryOverallocationBehaviour)
+      overallocInfo.pNext = std::exchange(info.pNext, &overallocInfo);
     
     VkDevice device = VK_NULL_HANDLE;
     
@@ -288,6 +318,20 @@ namespace dxvk {
   Rc<DxvkSurface> DxvkAdapter::createSurface(HINSTANCE instance, HWND window) {
     return new DxvkSurface(this, instance, window);
   }
+
+
+  void DxvkAdapter::notifyHeapMemoryAlloc(
+          uint32_t            heap,
+          VkDeviceSize        bytes) {
+    m_heapAlloc[heap] += bytes;
+  }
+
+  
+  void DxvkAdapter::notifyHeapMemoryFree(
+          uint32_t            heap,
+          VkDeviceSize        bytes) {
+    m_heapAlloc[heap] -= bytes;
+  }
   
   
   void DxvkAdapter::logAdapterInfo() const {
@@ -322,6 +366,12 @@ namespace dxvk {
   }
   
   
+  void DxvkAdapter::initHeapAllocInfo() {
+    for (uint32_t i = 0; i < m_heapAlloc.size(); i++)
+      m_heapAlloc[i] = 0;
+  }
+
+
   void DxvkAdapter::queryExtensions() {
     m_deviceExtensions = DxvkNameSet::enumDeviceExtensions(m_vki, m_handle);
   }
@@ -332,6 +382,14 @@ namespace dxvk {
     m_deviceInfo.core.sType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_PROPERTIES_2_KHR;
     m_deviceInfo.core.pNext = nullptr;
 
+    // Query info now so that we have basic device properties available
+    m_vki->vkGetPhysicalDeviceProperties2KHR(m_handle, &m_deviceInfo.core);
+
+    if (m_deviceInfo.core.properties.apiVersion >= VK_MAKE_VERSION(1, 1, 0)) {
+      m_deviceInfo.coreSubgroup.sType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_SUBGROUP_PROPERTIES;
+      m_deviceInfo.coreSubgroup.pNext = std::exchange(m_deviceInfo.core.pNext, &m_deviceInfo.coreSubgroup);
+    }
+
     if (m_deviceExtensions.supports(VK_EXT_TRANSFORM_FEEDBACK_EXTENSION_NAME)) {
       m_deviceInfo.extTransformFeedback.sType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_TRANSFORM_FEEDBACK_PROPERTIES_EXT;
       m_deviceInfo.extTransformFeedback.pNext = std::exchange(m_deviceInfo.core.pNext, &m_deviceInfo.extTransformFeedback);
@@ -342,6 +400,7 @@ namespace dxvk {
       m_deviceInfo.extVertexAttributeDivisor.pNext = std::exchange(m_deviceInfo.core.pNext, &m_deviceInfo.extVertexAttributeDivisor);
     }
 
+    // Query full device properties for all enabled extensions
     m_vki->vkGetPhysicalDeviceProperties2KHR(m_handle, &m_deviceInfo.core);
     
     // Nvidia reports the driver version in a slightly different format
