@@ -5,11 +5,16 @@
 namespace dxvk {
 
   struct DxvkOptions {
+    DxvkOptions() { }
     DxvkOptions(const Config& config);
 
     /// Allow allocating more memory from
     /// a heap than the device supports.
     bool allowMemoryOvercommit;
+
+    /// Number of compiler threads
+    /// when using the state cache
+    int32_t numCompilerThreads;
   };
 
 }
\ No newline at end of file
