@@ -5,15 +5,21 @@
 
 namespace dxvk::env {
 
-  std::string getEnvVar(const wchar_t* name) {
-    DWORD len = ::GetEnvironmentVariableW(name, nullptr, 0);
+  std::string getEnvVar(const std::string& name) {
+    int nameLen = ::MultiByteToWideChar(CP_ACP, 0, name.c_str(), name.length() + 1, nullptr, 0);
+
+    std::vector<WCHAR> wideName(nameLen);
+
+    ::MultiByteToWideChar(CP_ACP, 0, name.c_str(), name.length() + 1, wideName.data(), nameLen);
+
+    DWORD len = ::GetEnvironmentVariableW(wideName.data(), nullptr, 0);
     
     std::vector<WCHAR> result;
     
     while (len > result.size()) {
       result.resize(len);
       len = ::GetEnvironmentVariableW(
-        name, result.data(), result.size());
+        wideName.data(), result.data(), result.size());
     }
     
     result.resize(len);
